##  Comparing Diagram Versions
You can compare any two diagram versions, including draft versions that are not yet published. The side panel lists changes to fact sheets, dependencies, labels, and shapes, while the side-by-side view visually highlights these changes.
To help you quickly identify the type of change, highlights are color coded:
  * Green for additions
  * Red for removals
  * Yellow for modifications


To compare diagrams, do the following:
  1. In the Version History panel, hover over a version and choose the three-dot menu.
  2. Select Compare Changes.
  3. Select the version you want to compare.
In the side-by-side view, the older version appears on the left, and the newer version appears on the right.
  4. To view details for a change, choose a highlighted shape in the side-by-side view or choose the component name in the side panel.
  5. To exit the comparison, choose Exit Version Comparison.


Comparing Diagram Versions
![Gif of diagram comparison capabilities.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiob36d9ebefb88423c808f0f9c35958ca2_LowRes.gif)
